# SPDX-FileCopyrightText: © Antonio López Rivera <antonlopezr99@gmail.com>
# SPDX-License-Identifier: GPL-3.0-only

"""
3D
--
"""

from mpl_plotter.three_d.methods import line, scatter, surface, floating_text, \
                                        canvas, attributes
